@@ -1,7 +1,7 @@
 # -*- coding: UTF-8 -*-
 # vim: expandtab sw=4 ts=4 sts=4:
 #
-# Copyright © 2003 - 2015 Michal Čihař <michal@cihar.com>
+# Copyright © 2003 - 2016 Michal Čihař <michal@cihar.com>
 #
 # This file is part of python-gammu <http://wammu.eu/python-gammu/>
 #
@@ -41,7 +41,7 @@ logformat = none
 
 [smsd]
 commtimeout = 1
-debuglevel = 0
+debuglevel = 255
 logfile = stderr
 service = sql
 driver = sqlite3
@@ -147,6 +147,22 @@ class BasicDummyTest(DummyTest):
                 )
             remain = remain - 1
 
+    def test_getmemory(self):
+        state_machine = self.get_statemachine()
+
+        location = state_machine.AddMemory(
+            {
+                'MemoryType': 'SM',
+                'Entries': [
+                    {'Type': 'Number_Mobile', 'Value': '123456'},
+                    {'Type': 'Text_Name', 'Value': 'Jmeno'},
+                ]
+            }
+        )
+
+        read = state_machine.GetMemory('SM', location)
+        self.assertEqual(len(read['Entries']), 2)
+
     def test_calendar(self):
         state_machine = self.get_statemachine()
         status = state_machine.GetCalendarStatus()
