@@ -1,7 +1,7 @@
 # -*- coding: UTF-8 -*-
 # vim: expandtab sw=4 ts=4 sts=4:
 #
-# Copyright © 2003 - 2015 Michal Čihař <michal@cihar.com>
+# Copyright © 2003 - 2016 Michal Čihař <michal@cihar.com>
 #
 # This file is part of python-gammu <http://wammu.eu/python-gammu/>
 #
@@ -19,6 +19,7 @@
 # with this program; if not, write to the Free Software Foundation, Inc.,
 # 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
+from __future__ import print_function
 from .test_dummy import DummyTest
 import gammu.smsd
 import os
@@ -54,6 +55,8 @@ def get_script():
     else:
         dbver = 15
 
+    print('Gammu version {0}, SMSD DB version {1}'.format(version, dbver))
+
     return os.path.join(
         os.path.dirname(__file__),
         'data',
